__all__ = ['Drawing','Forms','IO','Threading']
from typing import Tuple, Set, Iterable, List


class AttachableMemberIdentifier:
    def __init__(self, declaringType: Type, memberName: str): ...
    @overload
    def Equals(self, obj: Object) -> bool: ...
    @overload
    def Equals(self, other: AttachableMemberIdentifier) -> bool: ...
    @property
    def DeclaringType(self) -> Type: ...
    @property
    def MemberName(self) -> str: ...
    def GetHashCode(self) -> int: ...
    def op_Equality(left: AttachableMemberIdentifier, right: AttachableMemberIdentifier) -> bool: ...
    def op_Inequality(left: AttachableMemberIdentifier, right: AttachableMemberIdentifier) -> bool: ...
    def ToString(self) -> str: ...


class AutoInitializeAttribute:
    def __init__(self, initialize: bool): ...
    @property
    def Initialize(self) -> bool: ...




class ContentPropertyAttribute:
    @overload
    def __init__(self): ...
    @overload
    def __init__(self, name: str): ...
    @property
    def Name(self) -> str: ...




class DefaultStyleProvider:
    def __init__(self): ...
    def Add(self, style: str, handler: Action) -> None: ...
    def add_StyleWidget(self, value: Action) -> None: ...
    def Clear(self) -> None: ...
    @property
    def Inherit(self) -> bool: ...
    def remove_StyleWidget(self, value: Action) -> None: ...
    @Inherit.setter
    def Inherit(self, value: bool) -> None: ...






class EtoEnvironment:
    @property
    def Is64BitProcess() -> bool: ...
    @property
    def Platform() -> OperatingSystemPlatform: ...
    def GetFolderPath(folder: EtoSpecialFolder) -> str: ...


class EtoMemberIdentifier(AttachableMemberIdentifier):
    def __init__(self, declaringType: Type, memberName: str): ...


class EtoSpecialFolder:
    ApplicationSettings = 0
    ApplicationResources = 1
    Documents = 2
    EntryExecutable = 3


class ExportHandlerAttribute(PlatformExtensionAttribute):
    def __init__(self, widgetType: Type, handlerType: Type): ...
    @property
    def HandlerType(self) -> Type: ...
    @property
    def WidgetType(self) -> Type: ...
    def Register(self, platform: Platform) -> None: ...


class ExportInitializerAttribute(PlatformExtensionAttribute):
    def __init__(self, initializerType: Type): ...
    @property
    def InitializerType(self) -> Type: ...
    def Register(self, platform: Platform) -> None: ...




class FileAction:
    OpenFile = 0
    SaveFile = 1
    SelectFolder = 2


class HandlerAttribute:
    def __init__(self, type: Type): ...
    @property
    def Type(self) -> Type: ...


class HandlerCreatedEventArgs:
    def __init__(self, instance: Object): ...
    @property
    def Instance(self) -> Object: ...


class ICallback:
    pass


class ICallbackSource:
    @property
    def Callback(self) -> Object: ...


class IControlObjectSource:
    @property
    def ControlObject(self) -> Object: ...


class IHandler:
    @property
    def ID(self) -> str: ...
    @property
    def NativeHandle(self) -> IntPtr: ...
    @property
    def Widget(self) -> Widget: ...
    def HandleEvent(self, id: str, defaultEvent: bool) -> None: ...
    def Initialize(self) -> None: ...
    @ID.setter
    def ID(self, value: str) -> None: ...
    @Widget.setter
    def Widget(self, value: Widget) -> None: ...


class IHandler:
    def GetFolderPath(self, folder: EtoSpecialFolder) -> str: ...


class IHandlerSource:
    @property
    def Handler(self) -> Object: ...


class IPlatformInitializer:
    def Initialize(self, platform: Platform) -> None: ...


class IStyleProvider:
    def ApplyCascadingStyle(self, container: Object, widget: Object, style: str) -> None: ...
    def ApplyDefault(self, widget: Object) -> None: ...
    def ApplyStyle(self, widget: Object, style: str) -> None: ...
    @property
    def Inherit(self) -> bool: ...


class NamespaceInfo:
    @overload
    def __init__(self, ns: str): ...
    @overload
    def __init__(self, ns: str, assembly: Assembly): ...
    @overload
    def FindResource(self) -> Stream: ...
    @overload
    def FindResource(self, resourceName: str) -> Stream: ...
    def FindType(self, typeName: str) -> Type: ...
    @property
    def Assembly(self) -> Assembly: ...
    @property
    def Namespace(self) -> str: ...
    @Assembly.setter
    def Assembly(self, value: Assembly) -> None: ...


class OperatingSystemPlatform:
    def __init__(self): ...
    @property
    def IsLinux(self) -> bool: ...
    @property
    def IsMac(self) -> bool: ...
    @property
    def IsMono(self) -> bool: ...
    @property
    def IsNetCore(self) -> bool: ...
    @property
    def IsUnix(self) -> bool: ...
    @property
    def IsWindows(self) -> bool: ...
    @property
    def IsWinRT(self) -> bool: ...


class Platform:
    def add_HandlerCreated(self, value: EventHandler) -> None: ...
    @overload
    def Add(self, instantiator: Func) -> None: ...
    @overload
    def Add(self, type: Type, instantiator: Func) -> None: ...
    def add_WidgetCreated(self, value: EventHandler) -> None: ...
    def Cache(self, cacheKey: Object) -> Dictionary: ...
    @overload
    def Create(self) -> T: ...
    @overload
    def Create(self, type: Type) -> Object: ...
    @overload
    def CreateShared(self) -> T: ...
    @overload
    def CreateShared(self, type: Type) -> Object: ...
    @overload
    def Find(self) -> Func: ...
    @overload
    def Find(self, type: Type) -> Func: ...
    @property
    def AllowReinitialize() -> bool: ...
    @property
    def Context(self) -> IDisposable: ...
    @property
    def Detect() -> Platform: ...
    @property
    def ID(self) -> str: ...
    @property
    def Instance() -> Platform: ...
    @property
    def IsAndroid(self) -> bool: ...
    @property
    def IsDesktop(self) -> bool: ...
    @property
    def IsGtk(self) -> bool: ...
    @property
    def IsIos(self) -> bool: ...
    @property
    def IsMac(self) -> bool: ...
    @property
    def IsMobile(self) -> bool: ...
    @property
    def IsValid(self) -> bool: ...
    @property
    def IsWinForms(self) -> bool: ...
    @property
    def IsWpf(self) -> bool: ...
    def Get(generatorType: str) -> Platform: ...
    @property
    def SupportedFeatures(self) -> PlatformFeatures: ...
    @overload
    def Initialize(platformType: str) -> None: ...
    @overload
    def Initialize(platform: Platform) -> None: ...
    @overload
    def Invoke(self, action: Action) -> None: ...
    @overload
    def Invoke(self, action: Func) -> T: ...
    @overload
    def LoadAssembly(self, assembly: Assembly) -> None: ...
    @overload
    def LoadAssembly(self, assemblyName: str) -> None: ...
    def remove_HandlerCreated(self, value: EventHandler) -> None: ...
    def remove_WidgetCreated(self, value: EventHandler) -> None: ...
    @AllowReinitialize.setter
    def AllowReinitialize(value: bool) -> None: ...
    @overload
    def Supports(self) -> bool: ...
    @overload
    def Supports(self, type: Type) -> bool: ...
    def ThreadStart(self) -> IDisposable: ...


class PlatformExtensionAttribute:
    @property
    def PlatformID(self) -> str: ...
    def Register(self, platform: Platform) -> None: ...
    @PlatformID.setter
    def PlatformID(self, value: str) -> None: ...
    def Supports(self, platform: Platform) -> bool: ...


class PlatformFeatures:
    #None = 0
    CustomCellSupportsControlView = 1
    DrawableWithTransparentContent = 2
    TabIndexWithCustomContainers = 4


class Platforms:
    pass


class PropertyStore:
    def __init__(self, parent: Object): ...
    def AddEvent(self, key: Object, value: Delegate) -> None: ...
    def AddHandlerEvent(self, key: str, value: Delegate) -> None: ...
    @overload
    def Create(self, key: Object) -> T: ...
    @overload
    def Create(self, key: Object, create: Func) -> T: ...
    @property
    def Parent(self) -> Object: ...
    @overload
    def Get(self, key: Object, defaultValue: T) -> T: ...
    @overload
    def Get(self, key: Object, defaultValue: Func) -> T: ...
    def GetCommand(self, key: Object) -> ICommand: ...
    def RemoveEvent(self, key: Object, value: Delegate) -> None: ...
    @overload
    def Set(self, key: Object, value: T, defaultValue: T) -> None: ...
    @overload
    def Set(self, key: Object, value: T, propertyChanged: Action, defaultValue: T) -> bool: ...
    @overload
    def Set(self, key: Object, value: T, propertyChanged: PropertyChangedEventHandler, defaultValue: T, propertyName: str) -> bool: ...
    def SetCommand(self, key: Object, value: ICommand, setEnabled: Action, addExecute: Action, removeExecute: Action, getParameter: Func) -> None: ...
    def TriggerEvent(self, key: Object, sender: Object, args: T) -> None: ...
    def TrySet(self, key: Object, value: T, defaultValue: T) -> bool: ...
    def UpdateCommandCanExecute(self, key: Object) -> None: ...


class RuntimeNamePropertyAttribute:
    def __init__(self, name: str): ...
    @property
    def Name(self) -> str: ...


class Style:
    @overload
    def Add(style: str, handler: StyleWidgetHandler) -> None: ...
    @overload
    def Add(style: str, styleHandler: StyleHandler) -> None: ...
    def add_StyleWidget(value: Action) -> None: ...
    @property
    def Provider() -> IStyleProvider: ...
    def remove_StyleWidget(value: Action) -> None: ...
    @Provider.setter
    def Provider(value: IStyleProvider) -> None: ...






class UnhandledExceptionEventArgs:
    def __init__(self, exception: Object, isTerminating: bool): ...
    @property
    def ExceptionObject(self) -> Object: ...
    @property
    def IsTerminating(self) -> bool: ...


class Widget:
    def add_StyleChanged(self, value: EventHandler) -> None: ...
    def Dispose(self) -> None: ...
    @property
    def ControlObject(self) -> Object: ...
    @property
    def Handler(self) -> Object: ...
    @property
    def ID(self) -> str: ...
    @property
    def IsDisposed(self) -> bool: ...
    @property
    def NativeHandle(self) -> IntPtr: ...
    @property
    def Platform(self) -> Platform: ...
    @property
    def Properties(self) -> PropertyStore: ...
    @property
    def Style(self) -> str: ...
    def remove_StyleChanged(self, value: EventHandler) -> None: ...
    @ID.setter
    def ID(self, value: str) -> None: ...
    @Style.setter
    def Style(self, value: str) -> None: ...
    def ToString(self) -> str: ...


class WidgetCreatedEventArgs:
    def __init__(self, instance: Widget): ...
    @property
    def Instance(self) -> Widget: ...









from typing import Tuple, Set, Iterable, List


class ThemedAboutDialogHandler:
    def __init__(self): ...
    @property
    def Copyright(self) -> str: ...
    @property
    def Designers(self) -> Set(str): ...
    @property
    def Developers(self) -> Set(str): ...
    @property
    def Documenters(self) -> Set(str): ...
    @property
    def License(self) -> str: ...
    @property
    def Logo(self) -> Image: ...
    @property
    def ProgramDescription(self) -> str: ...
    @property
    def ProgramName(self) -> str: ...
    @property
    def Title(self) -> str: ...
    @property
    def Version(self) -> str: ...
    @property
    def Website(self) -> Uri: ...
    @property
    def WebsiteLabel(self) -> str: ...
    @Copyright.setter
    def Copyright(self, value: str) -> None: ...
    @Designers.setter
    def Designers(self, value: Set(str)) -> None: ...
    @Developers.setter
    def Developers(self, value: Set(str)) -> None: ...
    @Documenters.setter
    def Documenters(self, value: Set(str)) -> None: ...
    @License.setter
    def License(self, value: str) -> None: ...
    @Logo.setter
    def Logo(self, value: Image) -> None: ...
    @ProgramDescription.setter
    def ProgramDescription(self, value: str) -> None: ...
    @ProgramName.setter
    def ProgramName(self, value: str) -> None: ...
    @Title.setter
    def Title(self, value: str) -> None: ...
    @Version.setter
    def Version(self, value: str) -> None: ...
    @Website.setter
    def Website(self, value: Uri) -> None: ...
    @WebsiteLabel.setter
    def WebsiteLabel(self, value: str) -> None: ...
    def ShowDialog(self, parent: Window) -> DialogResult: ...


class ThemedButtonSegmentedItemHandler:
    def __init__(self): ...


class ThemedCollectionEditor(Panel):
    def __init__(self): ...
    @property
    def DataStore(self) -> Iterable[Object]: ...
    @property
    def ElementType(self) -> Type: ...
    @property
    def ExtraContent(self) -> Control: ...
    @DataStore.setter
    def DataStore(self, value: Iterable[Object]) -> None: ...
    @ElementType.setter
    def ElementType(self, value: Type) -> None: ...
    @ExtraContent.setter
    def ExtraContent(self, value: Control) -> None: ...


class ThemedCollectionEditorHandler:
    def __init__(self): ...
    @property
    def DataStore(self) -> Iterable[Object]: ...
    @property
    def ElementType(self) -> Type: ...
    @DataStore.setter
    def DataStore(self, value: Iterable[Object]) -> None: ...
    @ElementType.setter
    def ElementType(self, value: Type) -> None: ...


class ThemedColorPickerHandler:
    def __init__(self): ...
    def AttachEvent(self, id: str) -> None: ...
    @property
    def AllowAlpha(self) -> bool: ...
    @property
    def Color(self) -> Color: ...
    @property
    def SupportsAllowAlpha(self) -> bool: ...
    @AllowAlpha.setter
    def AllowAlpha(self, value: bool) -> None: ...
    @Color.setter
    def Color(self, value: Color) -> None: ...


class ThemedDocumentControlHandler:
    def __init__(self): ...
    def AttachEvent(self, id: str) -> None: ...
    @property
    def AllowReordering(self) -> bool: ...
    @property
    def Enabled(self) -> bool: ...
    @property
    def Font(self) -> Font: ...
    @property
    def SelectedIndex(self) -> int: ...
    @property
    def TabPadding(self) -> Padding: ...
    def GetPage(self, index: int) -> DocumentPage: ...
    def GetPageCount(self) -> int: ...
    def InsertPage(self, index: int, page: DocumentPage) -> None: ...
    def OnLoad(self, e: EventArgs) -> None: ...
    def RemovePage(self, index: int) -> None: ...
    @AllowReordering.setter
    def AllowReordering(self, value: bool) -> None: ...
    @Enabled.setter
    def Enabled(self, value: bool) -> None: ...
    @Font.setter
    def Font(self, value: Font) -> None: ...
    @SelectedIndex.setter
    def SelectedIndex(self, value: int) -> None: ...
    @TabPadding.setter
    def TabPadding(self, value: Padding) -> None: ...


class ThemedDocumentPageHandler:
    def __init__(self): ...
    @property
    def Closable(self) -> bool: ...
    @property
    def Content(self) -> Control: ...
    @property
    def ContextMenu(self) -> ContextMenu: ...
    @property
    def Image(self) -> Image: ...
    @property
    def MinimumSize(self) -> Size: ...
    @property
    def Padding(self) -> Padding: ...
    @property
    def PropagateLoadEvents(self) -> bool: ...
    @property
    def Text(self) -> str: ...
    @Closable.setter
    def Closable(self, value: bool) -> None: ...
    @Content.setter
    def Content(self, value: Control) -> None: ...
    @ContextMenu.setter
    def ContextMenu(self, value: ContextMenu) -> None: ...
    @Image.setter
    def Image(self, value: Image) -> None: ...
    @MinimumSize.setter
    def MinimumSize(self, value: Size) -> None: ...
    @Padding.setter
    def Padding(self, value: Padding) -> None: ...
    @Text.setter
    def Text(self, value: str) -> None: ...


class ThemedExpanderHandler:
    def __init__(self): ...
    def AttachEvent(self, id: str) -> None: ...
    @property
    def CollapsedButtonText(self) -> str: ...
    @property
    def Content(self) -> Control: ...
    @property
    def ContextMenu(self) -> ContextMenu: ...
    @property
    def Expanded(self) -> bool: ...
    @property
    def ExpandedButtonText(self) -> str: ...
    @property
    def Header(self) -> Control: ...
    @property
    def MinimumSize(self) -> Size: ...
    @property
    def Padding(self) -> Padding: ...
    @CollapsedButtonText.setter
    def CollapsedButtonText(self, value: str) -> None: ...
    @Content.setter
    def Content(self, value: Control) -> None: ...
    @ContextMenu.setter
    def ContextMenu(self, value: ContextMenu) -> None: ...
    @Expanded.setter
    def Expanded(self, value: bool) -> None: ...
    @ExpandedButtonText.setter
    def ExpandedButtonText(self, value: str) -> None: ...
    @Header.setter
    def Header(self, value: Control) -> None: ...
    @MinimumSize.setter
    def MinimumSize(self, value: Size) -> None: ...
    @Padding.setter
    def Padding(self, value: Padding) -> None: ...


class ThemedFilePickerHandler:
    def __init__(self): ...
    def AttachEvent(self, id: str) -> None: ...
    def ClearFilters(self) -> None: ...
    @property
    def CurrentFilterIndex(self) -> int: ...
    @property
    def FileAction(self) -> FileAction: ...
    @property
    def FilePath(self) -> str: ...
    @property
    def Title(self) -> str: ...
    def InsertFilter(self, index: int, filter: FileFilter) -> None: ...
    def RemoveFilter(self, index: int) -> None: ...
    @CurrentFilterIndex.setter
    def CurrentFilterIndex(self, value: int) -> None: ...
    @FileAction.setter
    def FileAction(self, value: FileAction) -> None: ...
    @FilePath.setter
    def FilePath(self, value: str) -> None: ...
    @Title.setter
    def Title(self, value: str) -> None: ...


class ThemedFontPickerHandler:
    def __init__(self): ...
    def AttachEvent(self, id: str) -> None: ...
    @property
    def Value(self) -> Font: ...
    @Value.setter
    def Value(self, value: Font) -> None: ...


class ThemedMenuSegmentedItemHandler:
    def __init__(self): ...
    @property
    def CanSelect(self) -> bool: ...
    @property
    def Menu(self) -> ContextMenu: ...
    @property
    def MenuDelay(self) -> TimeSpan: ...
    @property
    def MenuIndicator(self) -> str: ...
    @property
    def Text(self) -> str: ...
    @CanSelect.setter
    def CanSelect(self, value: bool) -> None: ...
    @Menu.setter
    def Menu(self, value: ContextMenu) -> None: ...
    @MenuDelay.setter
    def MenuDelay(self, value: TimeSpan) -> None: ...
    @MenuIndicator.setter
    def MenuIndicator(self, value: str) -> None: ...
    @Text.setter
    def Text(self, value: str) -> None: ...


class ThemedPropertyGrid(Panel):
    def __init__(self): ...
    def add_PropertyValueChanged(self, value: EventHandler) -> None: ...
    def add_ShowCategoriesChanged(self, value: EventHandler) -> None: ...
    def CreateCellValueBinding(self) -> IndirectBinding: ...
    @property
    def PropertyCellTypes(self) -> List[PropertyCellType]: ...
    @property
    def SelectedObject(self) -> Object: ...
    @property
    def SelectedObjects(self) -> Iterable[Object]: ...
    @property
    def ShowCategories(self) -> bool: ...
    @property
    def ShowDescription(self) -> bool: ...
    @property
    def UseValueTypeDefaults(self) -> bool: ...
    def Refresh(self) -> None: ...
    def remove_PropertyValueChanged(self, value: EventHandler) -> None: ...
    def remove_ShowCategoriesChanged(self, value: EventHandler) -> None: ...
    @SelectedObject.setter
    def SelectedObject(self, value: Object) -> None: ...
    @SelectedObjects.setter
    def SelectedObjects(self, value: Iterable[Object]) -> None: ...
    @ShowCategories.setter
    def ShowCategories(self, value: bool) -> None: ...
    @ShowDescription.setter
    def ShowDescription(self, value: bool) -> None: ...
    @UseValueTypeDefaults.setter
    def UseValueTypeDefaults(self, value: bool) -> None: ...


class ThemedPropertyGridHandler:
    def __init__(self): ...
    def AttachEvent(self, id: str) -> None: ...
    @property
    def SelectedObject(self) -> Object: ...
    @property
    def SelectedObjects(self) -> Iterable[Object]: ...
    @property
    def ShowCategories(self) -> bool: ...
    @property
    def ShowDescription(self) -> bool: ...
    def Refresh(self) -> None: ...
    @SelectedObject.setter
    def SelectedObject(self, value: Object) -> None: ...
    @SelectedObjects.setter
    def SelectedObjects(self, value: Iterable[Object]) -> None: ...
    @ShowCategories.setter
    def ShowCategories(self, value: bool) -> None: ...
    @ShowDescription.setter
    def ShowDescription(self, value: bool) -> None: ...


class ThemedSegmentedButtonHandler:
    def __init__(self): ...
    def AttachEvent(self, id: str) -> None: ...
    def ClearItems(self) -> None: ...
    def ClearSelection(self) -> None: ...
    @property
    def SelectedIndex(self) -> int: ...
    @property
    def SelectedIndexes(self) -> Iterable[int]: ...
    @property
    def SelectionMode(self) -> SegmentedSelectionMode: ...
    @property
    def Spacing(self) -> int: ...
    def GetPreferredSize(self, availableSize: SizeF) -> SizeF: ...
    def InsertItem(self, index: int, item: SegmentedItem) -> None: ...
    def OnLoad(self, e: EventArgs) -> None: ...
    def OnPreLoad(self, e: EventArgs) -> None: ...
    def RemoveItem(self, index: int, item: SegmentedItem) -> None: ...
    def SelectAll(self) -> None: ...
    @SelectedIndex.setter
    def SelectedIndex(self, value: int) -> None: ...
    @SelectedIndexes.setter
    def SelectedIndexes(self, value: Iterable[int]) -> None: ...
    @SelectionMode.setter
    def SelectionMode(self, value: SegmentedSelectionMode) -> None: ...
    @Spacing.setter
    def Spacing(self, value: int) -> None: ...
    def SetItem(self, index: int, item: SegmentedItem) -> None: ...




class ThemedSpinnerDirection:
    Clockwise = 1
    CounterClockwise = -1


class ThemedSpinnerHandler:
    def __init__(self): ...
    @property
    def Direction(self) -> ThemedSpinnerDirection: ...
    @property
    def DisabledAlpha(self) -> Single: ...
    @property
    def ElementColor(self) -> Color: ...
    @property
    def ElementSize(self) -> Single: ...
    @property
    def Enabled(self) -> bool: ...
    @property
    def Increment(self) -> Single: ...
    @property
    def LineCap(self) -> PenLineCap: ...
    @property
    def LineThickness(self) -> Single: ...
    @property
    def Mode(self) -> ThemedSpinnerMode: ...
    @property
    def NumberOfElements(self) -> int: ...
    @property
    def NumberOfVisibleElements(self) -> int: ...
    @property
    def Speed(self) -> float: ...
    def OnLoadComplete(self, e: EventArgs) -> None: ...
    def OnUnLoad(self, e: EventArgs) -> None: ...
    @Direction.setter
    def Direction(self, value: ThemedSpinnerDirection) -> None: ...
    @DisabledAlpha.setter
    def DisabledAlpha(self, value: Single) -> None: ...
    @ElementColor.setter
    def ElementColor(self, value: Color) -> None: ...
    @ElementSize.setter
    def ElementSize(self, value: Single) -> None: ...
    @Enabled.setter
    def Enabled(self, value: bool) -> None: ...
    @Increment.setter
    def Increment(self, value: Single) -> None: ...
    @LineCap.setter
    def LineCap(self, value: PenLineCap) -> None: ...
    @LineThickness.setter
    def LineThickness(self, value: Single) -> None: ...
    @Mode.setter
    def Mode(self, value: ThemedSpinnerMode) -> None: ...
    @NumberOfElements.setter
    def NumberOfElements(self, value: int) -> None: ...
    @NumberOfVisibleElements.setter
    def NumberOfVisibleElements(self, value: int) -> None: ...
    @Speed.setter
    def Speed(self, value: float) -> None: ...


class ThemedSpinnerMode:
    Line = 0
    Circle = 1


class ThemedSplitterHandler:
    def __init__(self): ...
    @property
    def FixedPanel(self) -> SplitterFixedPanel: ...
    @property
    def Orientation(self) -> Orientation: ...
    @property
    def Panel1(self) -> Control: ...
    @property
    def Panel1MinimumSize(self) -> int: ...
    @property
    def Panel2(self) -> Control: ...
    @property
    def Panel2MinimumSize(self) -> int: ...
    @property
    def Position(self) -> int: ...
    @property
    def RelativePosition(self) -> float: ...
    @property
    def Splitter(self) -> Panel: ...
    @property
    def SplitterWidth(self) -> int: ...
    @FixedPanel.setter
    def FixedPanel(self, value: SplitterFixedPanel) -> None: ...
    @Orientation.setter
    def Orientation(self, value: Orientation) -> None: ...
    @Panel1.setter
    def Panel1(self, value: Control) -> None: ...
    @Panel1MinimumSize.setter
    def Panel1MinimumSize(self, value: int) -> None: ...
    @Panel2.setter
    def Panel2(self, value: Control) -> None: ...
    @Panel2MinimumSize.setter
    def Panel2MinimumSize(self, value: int) -> None: ...
    @Position.setter
    def Position(self, value: int) -> None: ...
    @RelativePosition.setter
    def RelativePosition(self, value: float) -> None: ...
    @SplitterWidth.setter
    def SplitterWidth(self, value: int) -> None: ...


class ThemedStepperHandler:
    def __init__(self): ...
    def AttachEvent(self, id: str) -> None: ...
    @property
    def DownText(self) -> str: ...
    @property
    def Enabled(self) -> bool: ...
    @property
    def Font(self) -> Font: ...
    @property
    def Orientation(self) -> Orientation: ...
    @property
    def UpText(self) -> str: ...
    @property
    def ValidDirection(self) -> StepperValidDirections: ...
    @DownText.setter
    def DownText(self, value: str) -> None: ...
    @Enabled.setter
    def Enabled(self, value: bool) -> None: ...
    @Font.setter
    def Font(self, value: Font) -> None: ...
    @Orientation.setter
    def Orientation(self, value: Orientation) -> None: ...
    @UpText.setter
    def UpText(self, value: str) -> None: ...
    @ValidDirection.setter
    def ValidDirection(self, value: StepperValidDirections) -> None: ...


class ThemedTextStepperHandler:
    def __init__(self): ...
    def AttachEvent(self, id: str) -> None: ...
    def Focus(self) -> None: ...
    @property
    def AutoSelectMode(self) -> AutoSelectMode: ...
    @property
    def BackgroundColor(self) -> Color: ...
    @property
    def CaretIndex(self) -> int: ...
    @property
    def Font(self) -> Font: ...
    @property
    def HasFocus(self) -> bool: ...
    @property
    def MaxLength(self) -> int: ...
    @property
    def PlaceholderText(self) -> str: ...
    @property
    def ReadOnly(self) -> bool: ...
    @property
    def Selection(self) -> Range: ...
    @property
    def ShowBorder(self) -> bool: ...
    @property
    def ShowStepper(self) -> bool: ...
    @property
    def Stepper(self) -> Stepper: ...
    @property
    def Text(self) -> str: ...
    @property
    def TextAlignment(self) -> TextAlignment: ...
    @property
    def TextBox(self) -> TextBox: ...
    @property
    def TextColor(self) -> Color: ...
    @property
    def ValidDirection(self) -> StepperValidDirections: ...
    def SelectAll(self) -> None: ...
    @AutoSelectMode.setter
    def AutoSelectMode(self, value: AutoSelectMode) -> None: ...
    @BackgroundColor.setter
    def BackgroundColor(self, value: Color) -> None: ...
    @CaretIndex.setter
    def CaretIndex(self, value: int) -> None: ...
    @Font.setter
    def Font(self, value: Font) -> None: ...
    @MaxLength.setter
    def MaxLength(self, value: int) -> None: ...
    @PlaceholderText.setter
    def PlaceholderText(self, value: str) -> None: ...
    @ReadOnly.setter
    def ReadOnly(self, value: bool) -> None: ...
    @Selection.setter
    def Selection(self, value: Range) -> None: ...
    @ShowBorder.setter
    def ShowBorder(self, value: bool) -> None: ...
    @ShowStepper.setter
    def ShowStepper(self, value: bool) -> None: ...
    @Text.setter
    def Text(self, value: str) -> None: ...
    @TextAlignment.setter
    def TextAlignment(self, value: TextAlignment) -> None: ...
    @TextColor.setter
    def TextColor(self, value: Color) -> None: ...
    @ValidDirection.setter
    def ValidDirection(self, value: StepperValidDirections) -> None: ...
